@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v2.1.2
+v2.1.3
 dpt_runtime/supports_mixin.py
 """
 
@@ -33,7 +33,7 @@ instance.
 
     # pylint: disable=assigning-non-slot
 
-    _mixin_slots_ = [ "supported_features" ]
+    _mixin_slots_ = ( "supported_features", )
     """
 Additional __slots__ used for inherited classes.
     """
